/* GROUP BREWPIXEL GRUNT WORKFLOW
=================================================== */

module.exports = function (grunt) {
	grunt.initConfig({
		/* =BrewPixel =JFG.

		1. Change the path variable below on a project basis.

		2. Run "grunt watch" to continually watch and reload.

		3. Run "grunt prod" to perform other actions to ready the project for publishing.

		*/

		path: "public_html/content/themes/ferret/",
		watch: {
			 triggerLiveReloadOnTheseFiles: { /* =BrewPixel =JFG. Source - https://github.com/gruntjs/grunt-contrib-watch/issues/87 */
				// We use this target to watch files that will trigger the livereload
				options: { 
					livereload: true 
				},
				files: [
					'<%= path %>js/*.js',
					'<%= path %>**/*.php',
					"<%= path %>page-templates/*.php",
					"<%= path %>img/*.svg",
					"<%= path %>img/*/*.svg",
					"<%= path %>img/*/*.jpg",
					"<%= path %>img/*/*.png",
				]
			}
		},

		copy: {
			prod1: { // =BrewPixel =JFG. Copy style-dev.css to style.css ready for production
				files: [
					{expand: true, // =BrewPixel =JFG. Needed when using cwd. https://github.com/gruntjs/grunt-contrib-copy/issues/90
					src: "<%= path %>style-dev.css",
					dest: "<%= path %>",
					rename: function(dest, src) { // =BrewPixel =JFG. Needs to be a function http://stackoverflow.com/questions/15271121/how-can-i-rename-files-with-grunt-based-on-the-respective-files-parent-folder
						return dest + "style.css";
					}},
				]
			}
		},

		postcss: {
			options: {
				processors: [
					require('postcss-custom-properties')() // minify the result
				]
			},
			dist: {
				src: "<%= path %>style.css"
			}
		},

		autoprefixer: {
			prod: {
				files: {
					"<%= path %>style.css": "<%= path %>style.css"
				}
			}
		},
	});


	grunt.registerTask("default", ["watch"]); /* Just run watch if no task is specified i.e. if you just run "grunt" */
	grunt.registerTask( "prod",// Name of our specific set of build tasks (e.g. doesn't run with watch and does not include dev tasks)
		[
		"copy:prod1",
		"postcss",
		"autoprefixer", // Vendor prefixes; allows us to do away with Compass
		"watch",
		]
	);


	grunt.loadNpmTasks("grunt-contrib-watch"); /* Watch files for changes */
	grunt.loadNpmTasks('grunt-contrib-copy'); /* Copy relative files and folders needed */
	grunt.loadNpmTasks('grunt-postcss');
	grunt.loadNpmTasks("grunt-autoprefixer");
};